precision mediump float;

const lowp float red_part = 0.2;
const lowp float green_part = 0.70980392;
const lowp float blue_part = 0.89803922;

// The input texture.
uniform sampler2D u_Texture;    

// Interpolated texture coordinate per fragment.
varying vec2 v_TexCoordinate;   

// The entry point for our fragment shader.
void main() {
	// Determine color strength for a given fragment.
	// Can sample any color component; it doesn't matter.
	float amplitude = texture2D(u_Texture, v_TexCoordinate).r;
	float distanceFromCenterLine = abs((v_TexCoordinate.t * 2.0) - 1.0);
	float colorStrength = mix(1.0, 0.0, distanceFromCenterLine / (amplitude + 0.001));

	// Determine color for a given fragment.
	lowp float interpolationRatio = (amplitude - 0.75) * 4.0;
	lowp float red = red_part + max(0.0, ((1.0 - red_part) * interpolationRatio));
	lowp float green = green_part - max(0.0, green_part * interpolationRatio);
	lowp float blue = blue_part - max(0.0, blue_part * interpolationRatio);
	lowp vec4 color = vec4(red, green, blue, 1.0);

    gl_FragColor = color * colorStrength;
}